@@ -28,10 +28,10 @@ from .engine import OptionEngine, APP_NAME
 
 class OptionMasterApp(BaseApp):
     """"""
-    app_name = APP_NAME
-    app_module = __module__
-    app_path = Path(__file__).parent
-    display_name = "期权交易"
-    engine_class = OptionEngine
-    widget_name = "OptionManager"
-    icon_name = str(app_path.joinpath("ui", "option.ico"))
+    app_name: str = APP_NAME
+    app_module: str = __module__
+    app_path: Path = Path(__file__).parent
+    display_name: str = "期权交易"
+    engine_class: OptionEngine = OptionEngine
+    widget_name: str = "OptionManager"
+    icon_name: str = str(app_path.joinpath("ui", "option.ico"))
